#!/usr/bin/python
#############################################################################
# Name:         check.py
# Purpose:      A configurable SSH agent utility for ZOPE3.
#               Simple online test facility (Views)
# Maintainer:   Torsten Kurbad <t.kurbad@iwm-kmrc.de>
# Copyright:    (c) iwm-kmrc.de KMRC - Knowledge Media Research Center
# License:      GPLv2
#############################################################################
__docformat__ = 'restructuredtext'

from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.publisher.browser import BrowserView

from sshagent.interfaces import ISSHAgent, ICheckSSHAgent


class CheckSSHAgentView(BrowserView):

    __used_for__ = ISSHAgent

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.__parent__ = context
        self.report = []

    def getUtilityInfo(self):
        """Returns a dict with information about the current configuration."""
        infoDict = {}
        infoDict['ssh_agent'] = self.context.ssh_agent
        infoDict['ssh_add'] = self.context.ssh_add
        infoDict['identities'] = len(self.context.identities)
        return infoDict


    def checkSSHAgent(self):
        """Check the SSHAgent functionality."""
        if self.request.get('run', None):
            testutil = ICheckSSHAgent(self.context)
            self._addInfo("<strong>"
                          "Check configuration of SSHAgent utility."
                          "</strong>")
            self.report = self.report + testutil.checkSSHAgent()
            self._addInfo(" ")
            self._addInfo("<strong>Checks done.</strong>")
            self._addInfo(" ")
    
            return self.report
        else:
            return ""

    def _addInfo(self, res):
        """Add traceback info to the report list"""
        self.report.append(res)

    check = ViewPageTemplateFile('check.pt')
